California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 029 - REQUIRES ON-SITE LICENSED MEDICAL PROFESSIONAL AT KIDNEY DIALYSIS CLINICS AND ESTABLISHES OTHER STATE REQUIREMENTS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1398274 | CALIFORNIANS FOR KIDNEY DIALYSIS PATIENT PROTECTION - YES ON 29, SPONSORED BY SERVICE EMPLOYEES INTERNATIONAL UNION - UNITED HEALTHCARE WORKERS WEST | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1373047 | SERVICE EMPLOYEES INTERNATIONAL UNION, UNITED HEALTHCARE WORKERS WEST (NONPROFIT 501 (C)(5)) - CALIFORNIANS FOR KIDNEY DIALYSIS PATIENT PROTECTION - YES ON 29 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1442293 | NO ON 29: STOP YET ANOTHER DANGEROUS DIALYSIS PROPOSITION, SPONSORED BY PATIENTS, DOCTORS, NURSES AND DIALYSIS PROVIDERS | OPPOSE